    Solves the problem of string methods to uppercase/lowercase the turkish character 'İ,i' and 'I,ı' for upper, lower, capitalize, title methods
    For example strings are converted as: "insan".capitalize() -> "Insan" but in Turkish language it should be converted as "İnsan", this class solves this problem.

    Usage: trStr("Bu Benim Cümlem").upper() -> "BU BENİM CÜMLEM"
